@@ -534,7 +534,7 @@ CommandOperationManager::runCommand(ProgramParameters& parameters)
     }
     
     AString commandSwitch;
-    commandSwitch = parameters.nextString("Command Name");
+    commandSwitch = fixUnicode(parameters.nextString("Command Name"));
     
     if (commandSwitch == "-help")
     {
@@ -600,9 +600,15 @@ bool CommandOperationManager::getGlobalOption(ProgramParameters& parameters, con
     parameters.setParameterIndex(0);//this ends up being slightly redundant, but whatever
     while (parameters.hasNext())//shouldn't be many global options, so do it the simple way
     {
-        AString test = parameters.nextString("global option");
+        bool hyphenReplaced = false;
+        AString testRaw = parameters.nextString("global option");
+        AString test = testRaw.fixUnicodeHyphens(&hyphenReplaced);
         if (test == optionString)
         {
+            if (hyphenReplaced)
+            {
+                CaretLogWarning("replaced non-ascii hyphen/dash characters in global option '" + testRaw + "' with ascii '-'");
+            }
             parameters.remove();
             arguments.clear();
             for (int i = 0; i < numArgs; ++i)
@@ -938,8 +944,8 @@ void CommandOperationManager::printGiftiHelp(const AString& /*programName*/)
     cout << "   called 'surface files', and must contain only the coordinate and triangle" << endl;
     cout << "   arrays.  Notably, other software may put data arrays (the equivalent of a" << endl;
     cout << "   metric file) into the same file as the geometry information.  Workbench does" << endl;
-    cout << "   not support these formats, and you must use other tools to separate the data" << endl;
-    cout << "   array from the geometry." << endl;
+    cout << "   not support this kind of combined format, and you must use other tools to" << endl;
+    cout << "   separate the data array from the geometry." << endl;
     cout << endl;//guide for wrap, assuming 80 columns:                                     |
     cout << "   For the full details of the GIFTI format, see" << endl;
     cout << "      http://www.nitrc.org/projects/gifti/" << endl;
@@ -972,3 +978,18 @@ void CommandOperationManager::printAllCommandsHelpInfo(const AString& programNam
         cout << iter->second->getHelpInformation(programName) << endl << endl;
     }
 }
+
+AString CommandOperationManager::fixUnicode(const AString& input)
+{
+    bool hyphenReplaced = false, otherNonAscii = false;
+    AString ret = input.fixUnicodeHyphens(&hyphenReplaced, &otherNonAscii);
+    if (otherNonAscii)
+    {
+        throw CaretException("found non-ascii character in operation switch '" + input + "', but one that is not recognized as a dash/hyphen/minus");
+    }
+    if (hyphenReplaced)
+    {
+        CaretLogWarning("replaced non-ascii hyphen/dash characters in operation switch '" + input + "' with ascii '-'");
+    }
+    return ret;
+}
