@@ -28,12 +28,17 @@
 
 #include "CaretAssert.h"
 #include "CaretLogger.h"
+#include "ControlPoint3D.h"
 #include "DataFileException.h"
 #include "FileInformation.h"
 #include "GiftiMetaData.h"
 #include "ImageCaptureSettings.h"
 #include "ImageFile.h"
+#include "Matrix4x4.h"
+#include "MathFunctions.h"
+#include "PaletteFile.h"
 #include "SceneClass.h"
+#include "VolumeFile.h"
 
 using namespace caret;
 
@@ -1361,6 +1366,225 @@ ImageFile::setImageFromByteArray(const QByteArray& byteArray,
     }
 }
 
+/**
+ * Convert this image into a Volume File.
+ *
+ * @param colorMode
+ *     Color mode for conversion.
+ * @param sformMatrix
+ *     Matrix used as NIFTI sform.
+ * @param paletteFile
+ *     Palette file used for coloring the voxels.
+ * @param errorMessageOut
+ *     Contains error message if conversion fails.
+ * @return
+ *     Pointer to volume file or NULL if there is an error.
+ *     Name of volume file is the name of the image but
+ *     the file extension is changed to a volume file extension.
+ *
+ */
+VolumeFile*
+ImageFile::convertToVolumeFile(const CONVERT_TO_VOLUME_COLOR_MODE colorMode,
+                               const std::vector<ControlPoint3D>& controlPointsIn,
+                               const PaletteFile* paletteFile,
+                               AString& errorMessageOut) const
+{
+    errorMessageOut.clear();
+    
+    std::vector<uint8_t> rgbaBytes;
+    int32_t width = 0;
+    int32_t height = 0;
+    getImageBytesRGBA(ImageFile::IMAGE_DATA_ORIGIN_AT_BOTTOM,
+                                   rgbaBytes,
+                                   width,
+                                   height);
+    if ((width <= 0)
+        || (height <= 0)) {
+        errorMessageOut = "Image width and/or height is invalid.";
+        return NULL;
+    }
+    
+    std::vector<ControlPoint3D> controlPoints = controlPointsIn;
+    const int32_t numControlPoints = static_cast<int32_t>(controlPoints.size());
+    if (numControlPoints < 3) {
+        errorMessageOut = "There must be at least three control points.";
+        return NULL;
+    }
+    
+    float pixelNormalVector[3];
+    ControlPoint3D::getSourceNormalVector(controlPoints, pixelNormalVector);
+    
+    std::cout << "Pixel Normal Vector: " << qPrintable(AString::fromNumbers(pixelNormalVector, 3, ",")) << std::endl;
+    
+    const float tinyValue = 0.00001;
+    if ((pixelNormalVector[2] < tinyValue)
+        && (pixelNormalVector[2] > -tinyValue)) {
+        errorMessageOut = "Control points need to be in a triangular shape; not a line";
+        return false;
+    }
+    
+    if (pixelNormalVector[2] < 0.0) {
+        std::cout << "Swapping coordinates so image normal vector is counter clockwise" << std::endl;
+        std::swap(controlPoints[0], controlPoints[2]);
+        ControlPoint3D::getSourceNormalVector(controlPoints, pixelNormalVector);
+        std::cout << "After Swapping Pixel Normal Vector: " << qPrintable(AString::fromNumbers(pixelNormalVector, 3, ",")) << std::endl;
+    }
+    
+    Matrix4x4 matrix;
+    if ( ! matrix.createLandmarkTransformMatrix(controlPoints,
+                                                errorMessageOut)) {
+        return NULL;
+    }
+    
+    float firstPixel[3] = { 0, 0, 0 };
+    matrix.multiplyPoint3(firstPixel);
+    std::cout << "First pixel coord: " << AString::fromNumbers(firstPixel, 3, ",") << std::endl;
+    
+    float lastPixel[3] = { width - 1, height - 1, 0 };
+    matrix.multiplyPoint3(lastPixel);
+    std::cout << "Last pixel coord: " << AString::fromNumbers(lastPixel, 3, ",") << std::endl;
+    
+    {
+        float bl[3] = { 0.0, 0.0, 0.0 };
+        matrix.multiplyPoint3(bl);
+        ControlPoint3D bottomLeft(0, 0, 0, bl[0], bl[1], bl[2]);
+        
+        float br[3] = { width - 1.0, 0.0, 0.0 };
+        matrix.multiplyPoint3(br);
+        ControlPoint3D bottomRight(width - 1.0, 0.0, 0.0, br[0], br[1], br[2]);
+        
+        float tr[3] = { width - 1.0, height - 1.0, 0.0 };
+        matrix.multiplyPoint3(tr);
+        ControlPoint3D topRight(width - 1.0, height - 1.0, 0.0, tr[0], tr[1], tr[2]);
+        
+        std::vector<ControlPoint3D> volumeControlPoints;
+        volumeControlPoints.push_back(bottomLeft);
+        volumeControlPoints.push_back(bottomRight);
+        volumeControlPoints.push_back(topRight);
+        
+        Matrix4x4 volumeMatrix;
+        if ( ! volumeMatrix.createLandmarkTransformMatrix(volumeControlPoints, errorMessageOut)) {
+            errorMessageOut.insert(0, "Volume Matrix: ");
+            return NULL;
+        }
+    }
+    
+    std::vector<int64_t> dimensions;
+    dimensions.push_back(width);  // I
+    dimensions.push_back(height); // J
+    dimensions.push_back(1); // K
+    
+    /*
+     * Convert matrix4x4 to volume file vector of vectors.
+     */
+    std::vector<float> row1;
+    std::vector<float> row2;
+    std::vector<float> row3;
+    std::vector<float> row4;
+
+    for (int j = 0; j < 4; j++) {
+        row1.push_back(matrix.getMatrixElement(0, j));
+        row2.push_back(matrix.getMatrixElement(1, j));
+        row3.push_back(matrix.getMatrixElement(2, j));
+        row4.push_back(matrix.getMatrixElement(3, j));
+    }
+    std::vector<std::vector<float> > indexToSpace;
+    indexToSpace.push_back(row1);
+    indexToSpace.push_back(row2);
+    indexToSpace.push_back(row3);
+    indexToSpace.push_back(row4);
+    
+    int64_t numComponents = 1;
+    SubvolumeAttributes::VolumeType whatType = SubvolumeAttributes::FUNCTIONAL;
+    switch (colorMode) {
+        case CONVERT_TO_VOLUME_COLOR_GRAYSCALE:
+            break;
+        case CONVERT_TO_VOLUME_COLOR_RGB:
+            numComponents = 3;
+            whatType = SubvolumeAttributes::RGB;
+            break;
+    }
+
+    VolumeFile* volumeFile = new VolumeFile(dimensions,
+                                    indexToSpace,
+                                    numComponents,
+                                    whatType);
+    
+    FileInformation fileInfo(getFileName());
+    const AString volumeFileName = FileInformation::assembleFileComponents(fileInfo.getAbsolutePath(),
+                                                                           fileInfo.getFileNameNoExtension(),
+                                                                           DataFileTypeEnum::toFileExtension(DataFileTypeEnum::VOLUME));
+    volumeFile->setFileName(volumeFileName);
+    
+    int32_t rgbaIndex = 0;
+    const int64_t k = 0;
+    const int64_t mapIndex = 0;
+    for (int64_t j = 0; j < height; j++) {
+        for (int64_t i = 0; i < width; i++) {
+            switch (colorMode) {
+                case CONVERT_TO_VOLUME_COLOR_GRAYSCALE:
+                {
+                    /*
+                     * Luminosity conversion from GIMP
+                     * http://docs.gimp.org/2.6/en/gimp-tool-desaturate.html
+                     */
+                    float intensity = ((rgbaBytes[rgbaIndex] * 0.21)
+                                       + (rgbaBytes[rgbaIndex + 1] * 0.72)
+                                       + (rgbaBytes[rgbaIndex + 2] * 0.07));
+                    if (intensity > 255.0) intensity = 255.0;
+                    else if (intensity < 0.0) intensity = 0.0;
+                    
+                    if (rgbaBytes[rgbaIndex + 3] <= 0.0) {
+                        intensity = 0.0;
+                    }
+                    volumeFile->setValue(intensity, i, j, k, mapIndex, 0);
+                    
+                    rgbaIndex += 4;
+                }
+                    break;
+                case CONVERT_TO_VOLUME_COLOR_RGB:
+                {
+                    CaretAssertVectorIndex(rgbaBytes, rgbaIndex);
+                    volumeFile->setValue(rgbaBytes[rgbaIndex], i, j, k, mapIndex, 0);
+                    CaretAssertVectorIndex(rgbaBytes, rgbaIndex);
+                    volumeFile->setValue(rgbaBytes[rgbaIndex+1], i, j, k, mapIndex, 1);
+                    CaretAssertVectorIndex(rgbaBytes, rgbaIndex);
+                    volumeFile->setValue(rgbaBytes[rgbaIndex+2], i, j, k, mapIndex, 2);
+                    if (numComponents == 4) {
+                        CaretAssertVectorIndex(rgbaBytes, rgbaIndex);
+                        volumeFile->setValue(rgbaBytes[rgbaIndex+3], i, j, k, mapIndex, 3);
+                    }
+                    rgbaIndex += 4;
+                }
+                    break;
+            }
+        }
+    }
+    
+    switch (colorMode) {
+        case CONVERT_TO_VOLUME_COLOR_GRAYSCALE:
+        {
+            PaletteColorMapping* pcm = volumeFile->getMapPaletteColorMapping(mapIndex);
+            pcm->setSelectedPaletteToGrayInterpolated();
+            pcm->setDisplayNegativeDataFlag(false);
+            pcm->setDisplayZeroDataFlag(false);
+            pcm->setDisplayPositiveDataFlag(true);
+            pcm->setScaleMode(PaletteScaleModeEnum::MODE_AUTO_SCALE);
+        }
+            break;
+        case CONVERT_TO_VOLUME_COLOR_RGB:
+            break;
+    }
+    
+    volumeFile->clearVoxelColoringForMap(mapIndex);
+    volumeFile->updateScalarColoringForMap(mapIndex,
+                                           paletteFile);
+
+    return volumeFile;
+}
+
+
+
 /**
  * Save file data from the scene.  For subclasses that need to
  * save to a scene, this method should be overriden.  sceneClass
