@@ -26,7 +26,6 @@
 #include <QGridLayout>
 #include <QLabel>
 #include <QLayout>
-//#include <QTabWidget>
 #include <QToolButton>
 
 #define __BORDER_SELECTION_VIEW_CONTROLLER_DECLARE__
@@ -38,6 +37,7 @@
 #include "BrainOpenGL.h"
 #include "BrowserTabContent.h"
 #include "CaretAssert.h"
+#include "CaretColorEnumComboBox.h"
 #include "GroupAndNameHierarchyViewController.h"
 #include "DisplayGroupEnumComboBox.h"
 #include "DisplayPropertiesBorders.h"
@@ -99,10 +99,10 @@ BorderSelectionViewController::BorderSelectionViewController(const int32_t brows
     m_tabWidget->setCurrentWidget(attributesWidget);
     
     QVBoxLayout* layout = new QVBoxLayout(this);
-    WuQtUtilities::setLayoutSpacingAndMargins(layout, 2, 2);
-    layout->addLayout(groupLayout);
-    layout->addSpacing(10);
+    //WuQtUtilities::setLayoutSpacingAndMargins(layout, 2, 2);
     layout->addWidget(m_bordersDisplayCheckBox);
+    layout->addWidget(WuQtUtilities::createHorizontalLineWidget());
+    layout->addLayout(groupLayout);
     layout->addWidget(m_tabWidget->getWidget(), 0, Qt::AlignLeft);
     layout->addStretch();
     
@@ -163,6 +163,12 @@ BorderSelectionViewController::createAttributesWidget()
     QObject::connect(m_coloringTypeComboBox, SIGNAL(itemActivated()),
                      this, SLOT(processAttributesChanges()));
     
+    QLabel* standardColorLabel = new QLabel("Standard Color");
+    m_standardColorComboBox = new CaretColorEnumComboBox(this);
+    m_standardColorComboBox->getWidget()->setToolTip("Select the standard color");
+    QObject::connect(m_standardColorComboBox, SIGNAL(colorSelected(const CaretColorEnum::Enum)),
+                     this, SLOT(processAttributesChanges()));
+
     float minLineWidth = 0;
     float maxLineWidth = 1000;
     //BrainOpenGL::getMinMaxLineWidth(minLineWidth,
@@ -175,8 +181,9 @@ BorderSelectionViewController::createAttributesWidget()
                                  maxLineWidth);
     m_lineWidthSpinBox->setSingleStep(1.0);
     m_lineWidthSpinBox->setDecimals(1);
-    m_lineWidthSpinBox->setSuffix("mm");
+    m_lineWidthSpinBox->setSuffix("px");
     m_lineWidthSpinBox->setToolTip("Adjust the width of borders drawn as lines.\n"
+                                   "Units is pixels\n"
                                    "The maximum width is dependent upon the \n"
                                    "graphics system.  There is no maximum value\n"
                                    "for this control and the drawn width of the \n"
@@ -213,6 +220,18 @@ BorderSelectionViewController::createAttributesWidget()
     QObject::connect(m_unstretchedLinesLengthSpinBox, SIGNAL(valueChanged(double)),
                      this, SLOT(processAttributesChanges()));
     
+    QLabel* aboveSurfaceLabel = new QLabel("Above Offset");
+    m_aboveSurfaceOffsetSpinBox =WuQFactory::newDoubleSpinBox();
+    m_aboveSurfaceOffsetSpinBox->setFixedWidth(80);
+    m_aboveSurfaceOffsetSpinBox->setRange(   0.0,
+                                           100.0);
+    m_aboveSurfaceOffsetSpinBox->setSingleStep(0.1);
+    m_aboveSurfaceOffsetSpinBox->setDecimals(1);
+    m_aboveSurfaceOffsetSpinBox->setToolTip(WuQtUtilities::createWordWrappedToolTipText("Moves surface away from borders (in depth) so that borders are above surface.  "
+                                                                                        "Use with caution."));
+    QObject::connect(m_aboveSurfaceOffsetSpinBox, SIGNAL(valueChanged(double)),
+                     this, SLOT(processAttributesChanges()));
+    
     QWidget* gridWidget = new QWidget();
     QGridLayout* gridLayout = new QGridLayout(gridWidget);
     WuQtUtilities::setLayoutSpacingAndMargins(gridLayout, 8, 2);
@@ -227,6 +246,9 @@ BorderSelectionViewController::createAttributesWidget()
     gridLayout->addWidget(coloringLabel, row, 0);
     gridLayout->addWidget(m_coloringTypeComboBox->getWidget(), row, 1);
     row++;
+    gridLayout->addWidget(standardColorLabel, row, 0);
+    gridLayout->addWidget(m_standardColorComboBox->getWidget(), row, 1);
+    row++;
     gridLayout->addWidget(lineWidthLabel, row, 0);
     gridLayout->addWidget(m_lineWidthSpinBox, row, 1);
     row++;
@@ -235,6 +257,9 @@ BorderSelectionViewController::createAttributesWidget()
     row++;
     gridLayout->addWidget(m_enableUnstretchedLinesCheckBox, row, 0);
     gridLayout->addWidget(m_unstretchedLinesLengthSpinBox, row, 1);
+    row++;
+    gridLayout->addWidget(aboveSurfaceLabel, row, 0);
+    gridLayout->addWidget(m_aboveSurfaceOffsetSpinBox, row, 1);
     
     gridWidget->setSizePolicy(QSizePolicy::Fixed,
                               QSizePolicy::Fixed);
@@ -260,8 +285,9 @@ BorderSelectionViewController::processAttributesChanges()
     const int drawTypeInteger = m_drawTypeComboBox->itemData(selectedDrawTypeIndex).toInt();
     const BorderDrawingTypeEnum::Enum selectedDrawingType = static_cast<BorderDrawingTypeEnum::Enum>(drawTypeInteger);
     const FeatureColoringTypeEnum::Enum selectedColoringType = m_coloringTypeComboBox->getSelectedItem<FeatureColoringTypeEnum, FeatureColoringTypeEnum::Enum>();
-
-    BrowserTabContent* browserTabContent = 
+    const CaretColorEnum::Enum standardColorType = m_standardColorComboBox->getSelectedColor();
+    
+    BrowserTabContent* browserTabContent =
     GuiManager::get()->getBrowserTabContentForBrowserWindow(m_browserWindowIndex, true);
     if (browserTabContent == NULL) {
         return;
@@ -281,6 +307,9 @@ BorderSelectionViewController::processAttributesChanges()
     dpb->setColoringType(displayGroup,
                          browserTabIndex,
                          selectedColoringType);
+    dpb->setStandardColorType(displayGroup,
+                           browserTabIndex,
+                           standardColorType);
     dpb->setLineWidth(displayGroup,
                       browserTabIndex,
                       m_lineWidthSpinBox->value());
@@ -293,6 +322,7 @@ BorderSelectionViewController::processAttributesChanges()
     dpb->setUnstretchedLinesLength(displayGroup,
                                    browserTabIndex,
                                    m_unstretchedLinesLengthSpinBox->value());
+    dpb->setAboveSurfaceOffset(m_aboveSurfaceOffsetSpinBox->value());
     
     EventManager::get()->sendEvent(EventGraphicsUpdateAllWindows().getPointer());
     
@@ -390,6 +420,8 @@ BorderSelectionViewController::updateBorderViewController()
     
     m_coloringTypeComboBox->setSelectedItem<FeatureColoringTypeEnum, FeatureColoringTypeEnum::Enum>(dpb->getColoringType(displayGroup,
                                                                                                                          browserTabIndex));
+    m_standardColorComboBox->setSelectedColor(dpb->getStandardColorType(displayGroup,
+                                                                        browserTabIndex));
     m_lineWidthSpinBox->blockSignals(true);
     m_lineWidthSpinBox->setValue(dpb->getLineWidth(displayGroup,
                                                    browserTabIndex));
@@ -406,6 +438,10 @@ BorderSelectionViewController::updateBorderViewController()
     m_unstretchedLinesLengthSpinBox->setValue(dpb->getUnstretchedLinesLength(displayGroup,
                                                                              browserTabIndex));
     m_unstretchedLinesLengthSpinBox->blockSignals(false);
+    
+    m_aboveSurfaceOffsetSpinBox->blockSignals(true);
+    m_aboveSurfaceOffsetSpinBox->setValue(dpb->getAboveSurfaceOffset());
+    m_aboveSurfaceOffsetSpinBox->blockSignals(false);
 }
 
 /**
