@@ -92,7 +92,8 @@ IdentifyBrainordinateDialog::IdentifyBrainordinateDialog(QWidget* parent)
      * Filter file types for CIFTI type files
      */
     std::vector<DataFileTypeEnum::Enum> allDataFileTypes;
-    DataFileTypeEnum::getAllEnums(allDataFileTypes);
+    DataFileTypeEnum::getAllEnums(allDataFileTypes,
+                                  DataFileTypeEnum::OPTIONS_INCLUDE_CONNECTIVITY_DENSE_DYNAMIC);
     
     std::vector<DataFileTypeEnum::Enum> supportedCiftiRowFileTypes;
     std::vector<DataFileTypeEnum::Enum> supportedLabelFileTypes;
@@ -106,11 +107,16 @@ IdentifyBrainordinateDialog::IdentifyBrainordinateDialog(QWidget* parent)
         ParcelSourceDimension parcelSourceDimension = PARCEL_SOURCE_INVALID_DIMENSION;
         
         switch (dataFileType) {
+            case DataFileTypeEnum::ANNOTATION:
+                break;
             case DataFileTypeEnum::BORDER:
                 break;
             case DataFileTypeEnum::CONNECTIVITY_DENSE:
                 ciftiRowFlag = true;
                 break;
+            case DataFileTypeEnum::CONNECTIVITY_DENSE_DYNAMIC:
+                ciftiRowFlag = true;
+                break;
             case DataFileTypeEnum::CONNECTIVITY_DENSE_LABEL:
                 labelFileFlag = true;
                 break;
